@@ -18,16 +18,16 @@
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
+#include <string.h>
+#include <stdlib.h>
+
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <gtk/gtkliststore.h>
 #include <gtk/gtktreemodel.h>
 #include <gnome-keyring.h>
 
-#include <string.h>
-#include <stdlib.h>
-
 #include "gnome-keyring-manager.h"
-#include "gnome-keyring-manager-i18n.h"
 #include "gnome-keyring-manager-util.h"
 #include "gnome-keyring-manager-keyring-editor.h"
 #include "gnome-keyring-manager-keyring-manager.h"
@@ -38,77 +38,27 @@ struct _GKMKeyringManagerPrivate
   char *default_keyring;
 };
 
-static void gkm_keyring_manager_class_init (GKMKeyringManagerClass *class);
-static void gkm_keyring_manager_init       (GKMKeyringManager *dialog);
 static void gkm_keyring_manager_finalize   (GObject *object);
 
 static void gkm_keyring_manager_initialize_tree_model (GKMKeyringManager *manager);
 
-static void close_action_callback (GtkAction *action, 
-				   GKMKeyringManager *manager);
-static void open_keyring_action_callback (GtkWidget *button, 
-					  GKMKeyringManager *manager);
-static void lock_unlock_keyring_action_callback (GtkWidget *widget, 
-						 GKMKeyringManager *manager);
-static void set_default_keyring_action_callback (GtkWidget *widget, 
-						 GKMKeyringManager *manager);
-static void toggle_view_column_action_callback (GtkToggleAction *action, 
-						GtkWidget *widget);
-static void about_action_callback (GtkAction *action, 
-				   GKMKeyringManager *manager);
-
-static gboolean keyring_tree_context_menu_callback (GtkWidget *tree_view, 
-						    GKMKeyringManager *window);
-static gboolean keyring_tree_button_press_callback (GtkWidget *tree_view, 
-						    GdkEventButton *event, 
-						    GKMKeyringManager *window);
-
-static void gkm_keyring_manager_update_keyrings (GKMKeyringManager *transient_parent);
-static void gkm_keyring_manager_update_keyring_info (GKMKeyringManager *manager,
+static void gkm_keyring_manager_update_keyrings (GKMKeyringManager *self);
+static void gkm_keyring_manager_update_keyring_info (GKMKeyringManager *self,
 						     const char *keyring, 
 						     GtkTreeIter *iter);
-static void gkm_keyring_manager_update_default_keyring (GKMKeyringManager *manager);
+static void gkm_keyring_manager_update_default_keyring (GKMKeyringManager *self);
+
+G_DEFINE_TYPE (GKMKeyringManager, gkm_keyring_manager, G_TYPE_OBJECT);
 
 /********************************************************************
  * GKMKeyringManager and GKMKeyringManagerClass
  */
 
-static GObjectClass *parent_class = NULL;
-
-GType
-gkm_keyring_manager_get_type (void)
-{
-  static GType type = 0;
-  
-  if (!type)
-    {
-      static const GTypeInfo info =
-      {
-	sizeof (GKMKeyringManagerClass),
-	NULL,           /* base_init */
-	NULL,           /* base_finalize */
-	(GClassInitFunc) gkm_keyring_manager_class_init,
-	NULL,           /* class_finalize */
-	NULL,           /* class_data */
-	sizeof (GKMKeyringManager),
-	0,              /* n_preallocs */
-	(GInstanceInitFunc) gkm_keyring_manager_init,
-        0
-      };
-
-      type = g_type_register_static (G_TYPE_OBJECT, "GKMKeyringManager", &info, 0);
-    }
-  
-  return type;
-}
-
 static void
 gkm_keyring_manager_class_init (GKMKeyringManagerClass *class)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
 
-  parent_class = g_type_class_peek_parent (class);
-
   gobject_class->finalize = gkm_keyring_manager_finalize;
 }
 
@@ -135,7 +85,7 @@ gkm_keyring_manager_finalize (GObject *object)
 
   g_free (manager->priv);
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (gkm_keyring_manager_parent_class)->finalize (object);
 }
 
 GObject *
@@ -340,94 +290,94 @@ gkm_keyring_manager_delete_keyring (GKMKeyringManager *self,
  * Locking and unlocking keyrings
  */
 
-typedef struct _LockUnlockKeyringCallbackData
-{
-  GtkTreeRowReference *row;
-  GKMKeyringManager *manager;
-  gchar *keyring_name;
-} LockUnlockKeyringCallbackData;
+/* typedef struct _LockUnlockKeyringCallbackData */
+/* { */
+/*   GtkTreeRowReference *row; */
+/*   GKMKeyringManager *manager; */
+/*   gchar *keyring_name; */
+/* } LockUnlockKeyringCallbackData; */
 
-static void
-lock_unlock_keyring_callback_data_free (LockUnlockKeyringCallbackData *data)
-{
-  gtk_tree_row_reference_free (data->row);
-  g_free (data->keyring_name);
-  g_free (data);
-}
+/* static void */
+/* lock_unlock_keyring_callback_data_free (LockUnlockKeyringCallbackData *data) */
+/* { */
+/*   gtk_tree_row_reference_free (data->row); */
+/*   g_free (data->keyring_name); */
+/*   g_free (data); */
+/* } */
 
-static LockUnlockKeyringCallbackData *
-lock_unlock_keyring_callback_data_clone (LockUnlockKeyringCallbackData *data)
-{
-  LockUnlockKeyringCallbackData *clone;
+/* static LockUnlockKeyringCallbackData * */
+/* lock_unlock_keyring_callback_data_clone (LockUnlockKeyringCallbackData *data) */
+/* { */
+/*   LockUnlockKeyringCallbackData *clone; */
 
-  clone = g_new (LockUnlockKeyringCallbackData, 1);
-  clone->row = gtk_tree_row_reference_copy (data->row);
-  clone->manager = data->manager;
-  clone->keyring_name = g_strdup (data->keyring_name);
+/*   clone = g_new (LockUnlockKeyringCallbackData, 1); */
+/*   clone->row = gtk_tree_row_reference_copy (data->row); */
+/*   clone->manager = data->manager; */
+/*   clone->keyring_name = g_strdup (data->keyring_name); */
 
-  return clone;
-}
+/*   return clone; */
+/* } */
 
-static void 
-lock_keyring_callback (GnomeKeyringResult             result,
-                       LockUnlockKeyringCallbackData *data)
-{
-  GtkTreePath *path;
-  GtkTreeIter iter;
+/* static void  */
+/* lock_keyring_callback (GnomeKeyringResult             result, */
+/*                        LockUnlockKeyringCallbackData *data) */
+/* { */
+/*   GtkTreePath *path; */
+/*   GtkTreeIter iter; */
 
-  if (result != GNOME_KEYRING_RESULT_OK)
-    {
-      complain_about_gnome_keyring_bad_result (GTK_WINDOW (data->manager), result);
+/*   if (result != GNOME_KEYRING_RESULT_OK) */
+/*     { */
+/*       complain_about_gnome_keyring_bad_result (GTK_WINDOW (data->manager), result); */
 
-      return;
-    } 
+/*       return; */
+/*     }  */
 
-  if (!gtk_tree_row_reference_valid (data->row))
-    {
-      g_warning (_("A row disapeared while we were waiting for it to be locked..."));
+/*   if (!gtk_tree_row_reference_valid (data->row)) */
+/*     { */
+/*       g_warning (_("A row disappeared while we were waiting for it to be locked...")); */
 
-      return;
-    }
+/*       return; */
+/*     } */
 
-  path = gtk_tree_row_reference_get_path (data->row);
-  gtk_tree_model_get_iter (GTK_TREE_MODEL (data->manager->priv->keyrings), &iter, path);
-  gtk_tree_path_free (path);
+/*   path = gtk_tree_row_reference_get_path (data->row); */
+/*   gtk_tree_model_get_iter (GTK_TREE_MODEL (data->manager->priv->keyrings), &iter, path); */
+/*   gtk_tree_path_free (path); */
 
-  gtk_list_store_set (data->manager->priv->keyrings, &iter, MANAGER_COLUMN_LOCK,
-		      LOCKED_ICON, -1);
-} 
+/*   gtk_list_store_set (data->manager->priv->keyrings, &iter, MANAGER_COLUMN_LOCK, */
+/* 		      LOCKED_ICON, -1); */
+/* }  */
 
-static void 
-unlock_keyring_callback (GnomeKeyringResult             result,
-                         LockUnlockKeyringCallbackData *data)
-{
-  GtkTreePath *path;
-  GtkTreeIter iter;
+/* static void  */
+/* unlock_keyring_callback (GnomeKeyringResult             result, */
+/*                          LockUnlockKeyringCallbackData *data) */
+/* { */
+/*   GtkTreePath *path; */
+/*   GtkTreeIter iter; */
 
-  if (result != GNOME_KEYRING_RESULT_OK)
-    {
-      complain_about_gnome_keyring_bad_result (GTK_WINDOW (data->manager), 
-					       result);
+/*   if (result != GNOME_KEYRING_RESULT_OK) */
+/*     { */
+/*       complain_about_gnome_keyring_bad_result (GTK_WINDOW (data->manager),  */
+/* 					       result); */
 
-      return;
-    } 
+/*       return; */
+/*     }  */
 
-  if (!gtk_tree_row_reference_valid (data->row))
-    {
-      return;
-    }
+/*   if (!gtk_tree_row_reference_valid (data->row)) */
+/*     { */
+/*       return; */
+/*     } */
 
-  path = gtk_tree_row_reference_get_path (data->row);
-  if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (data->manager->priv->keyrings), 
-				&iter, path))
-    {
-      g_assert_not_reached ();
-    }
-  gtk_tree_path_free (path);
+/*   path = gtk_tree_row_reference_get_path (data->row); */
+/*   if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (data->manager->priv->keyrings),  */
+/* 				&iter, path)) */
+/*     { */
+/*       g_assert_not_reached (); */
+/*     } */
+/*   gtk_tree_path_free (path); */
 
-  gtk_list_store_set (data->manager->priv->keyrings, &iter, MANAGER_COLUMN_LOCK,
-		      UNLOCKED_ICON, -1);
-}
+/*   gtk_list_store_set (data->manager->priv->keyrings, &iter, MANAGER_COLUMN_LOCK, */
+/* 		      UNLOCKED_ICON, -1); */
+/* } */
 
 /* static void */
 /* unlock_keyring_password_callback (GKMPasswordDialog             *dialog, */
@@ -646,50 +596,50 @@ unlock_keyring_callback (GnomeKeyringResult             result,
  * Set the default keyring
  */
 
-static void
-set_default_keyring_worker_callback (GnomeKeyringResult  result,
-                                     GKMKeyringManager  *manager)
-{
-  if (result != GNOME_KEYRING_RESULT_OK)
-    {
-      /* FIXME: tell the user about this. */
-      g_warning (_("Failed set the default keyring."));
+/* static void */
+/* set_default_keyring_worker_callback (GnomeKeyringResult  result, */
+/*                                      GKMKeyringManager  *manager) */
+/* { */
+/*   if (result != GNOME_KEYRING_RESULT_OK) */
+/*     { */
+/*       /\* FIXME: tell the user about this. *\/ */
+/*       g_warning (_("Failed set the default keyring.")); */
 
-      return;
-    }
+/*       return; */
+/*     } */
 
-  gkm_keyring_manager_update_default_keyring (manager);
-}
+/*   gkm_keyring_manager_update_default_keyring (manager); */
+/* } */
 
-static void
-set_default_keyring_action_callback (GtkWidget         *widget G_GNUC_UNUSED,
-                                     GKMKeyringManager *manager)
-{
-  GtkTreeView *tree_view;
-  GtkTreeSelection *selection;
-  GtkTreeModel *model;
-  GtkTreeIter iter;
+/* static void */
+/* set_default_keyring_action_callback (GtkWidget         *widget G_GNUC_UNUSED, */
+/*                                      GKMKeyringManager *manager) */
+/* { */
+/*   GtkTreeView *tree_view; */
+/*   GtkTreeSelection *selection; */
+/*   GtkTreeModel *model; */
+/*   GtkTreeIter iter; */
 
-  g_return_if_fail (GTK_IS_WINDOW (manager));
+/*   g_return_if_fail (GTK_IS_WINDOW (manager)); */
 
-  tree_view = g_object_get_data (G_OBJECT (manager), "tree-view");
+/*   tree_view = g_object_get_data (G_OBJECT (manager), "tree-view"); */
 
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
+/*   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view)); */
 
-  if (gtk_tree_selection_get_selected (selection, &model, &iter))
-    {
-      char *keyring;
+/*   if (gtk_tree_selection_get_selected (selection, &model, &iter)) */
+/*     { */
+/*       char *keyring; */
 
-      gtk_tree_model_get (GTK_TREE_MODEL (manager->priv->keyrings), &iter, 
-			  MANAGER_COLUMN_KEYRING, &keyring, -1);
+/*       gtk_tree_model_get (GTK_TREE_MODEL (manager->priv->keyrings), &iter,  */
+/* 			  MANAGER_COLUMN_KEYRING, &keyring, -1); */
 
-      gnome_keyring_set_default_keyring (keyring, 
-                                         (GnomeKeyringOperationDoneCallback) set_default_keyring_worker_callback,
-                                         manager, NULL);
+/*       gnome_keyring_set_default_keyring (keyring,  */
+/*                                          (GnomeKeyringOperationDoneCallback) set_default_keyring_worker_callback, */
+/*                                          manager, NULL); */
 
-      g_free (keyring);
-    }
-}
+/*       g_free (keyring); */
+/*     } */
+/* } */
 
 /********************************************************************
  * Searching for a keyring
@@ -984,16 +934,10 @@ update_keyrings_worker_callback (GnomeKeyringResult  result,
   gkm_keyring_manager_update_default_keyring (manager);
 }
 
-/**
- * gkm_keyring_manager_update_keyrings:
- * @transient_parent: a #GtkWindow on which to make error dialogs transient_for, or NULL
- *
- * Update the contents of the global keyrings #GtkListStore.
- **/
-
 static void
-gkm_keyring_manager_update_keyrings (GKMKeyringManager *manager)
+gkm_keyring_manager_update_keyrings (GKMKeyringManager *self)
 {
-  gnome_keyring_list_keyring_names ((GnomeKeyringOperationGetListCallback) update_keyrings_worker_callback, 
-                                    manager, NULL);
+  gnome_keyring_list_keyring_names ((GnomeKeyringOperationGetListCallback) 
+				    update_keyrings_worker_callback, 
+                                    self, NULL);
 }
